@@ -23,6 +23,7 @@ import json
 import logging
 import os
 import platform
+import re
 import socket
 import subprocess
 import sys
@@ -392,7 +393,7 @@ _opts = [
 # Passwords, tokens, hashes
 _auth_opts = [
     cfg.StrOpt('undercloud_db_password',
-               help=('Password used for MySQL databases. '
+               help=('Password used for MySQL root user. '
                      'If left unset, one will be automatically generated.')
                ),
     cfg.StrOpt('undercloud_admin_token',
@@ -570,6 +571,15 @@ def _run_command(args, env=None, name=None):
     """
     if name is None:
         name = args[0]
+
+    if env is None:
+        env = os.environ
+    env = env.copy()
+
+    # When running a localized python script, we need to tell it that we're
+    # using utf-8 for stdout, otherwise it can't tell because of the pipe.
+    env['PYTHONIOENCODING'] = 'utf8'
+
     try:
         return subprocess.check_output(args,
                                        stderr=subprocess.STDOUT,
@@ -588,6 +598,15 @@ def _run_live_command(args, env=None, name=None):
     """
     if name is None:
         name = args[0]
+
+    if env is None:
+        env = os.environ
+    env = env.copy()
+
+    # When running a localized python script, we need to tell it that we're
+    # using utf-8 for stdout, otherwise it can't tell because of the pipe.
+    env['PYTHONIOENCODING'] = 'utf8'
+
     process = subprocess.Popen(args, env=env,
                                stdout=subprocess.PIPE,
                                stderr=subprocess.STDOUT)
@@ -1337,6 +1356,27 @@ def _run_yum_update(instack_env):
     LOG.info('yum-update completed successfully')
 
 
+def _get_ovs_interfaces():
+    interfaces = glob.glob('/etc/sysconfig/network-scripts/ifcfg-*')
+    pattern = "OVSIntPort"
+    ovs_interfaces = []
+    for interface in interfaces:
+        with open(interface, "r") as text:
+            for line in text:
+                if re.findall(pattern, line):
+                    # FIXME (holser). It might be better to get interface from
+                    # DEVICE rather than name of file.
+                    ovs_interfaces.append(interface.split('-')[-1])
+    return ovs_interfaces
+
+
+def _run_restore_ovs_interfaces(interfaces):
+    for interface in interfaces:
+        LOG.info('Running restart OVS interface %s', interface)
+        _run_command(['sudo', 'ifup', interface])
+        LOG.info('Restart OVS interface %s completed successfully', interface)
+
+
 def _run_orc(instack_env):
     args = ['sudo', 'os-refresh-config']
     LOG.info('Running os-refresh-config')
@@ -1776,6 +1816,7 @@ def install(instack_root, upgrade=False):
         _validate_configuration()
         instack_env = _generate_environment(instack_root)
         _generate_init_data(instack_env)
+        ovs_interfaces = _get_ovs_interfaces()
         if upgrade:
             # Even if we backport https://review.openstack.org/#/c/457478/
             # into stable branches of puppet-ironic, we still need a way
@@ -1788,10 +1829,17 @@ def install(instack_root, upgrade=False):
             _die_tuskar_die()
         if CONF.undercloud_update_packages:
             _run_yum_clean_all(instack_env)
+            if ovs_interfaces:
+                _run_restore_ovs_interfaces(ovs_interfaces)
             _run_yum_update(instack_env)
         _handle_upgrade_fact(upgrade)
         _run_instack(instack_env)
         _run_orc(instack_env)
+        # FIXME (holser). The RC of issue is in OVS flow restore. Once
+        # 'systemctl reload openvswitch' is fixed ovs port restoration can be
+        # removed.
+        if ovs_interfaces:
+            _run_restore_ovs_interfaces(ovs_interfaces)
         _post_config(instack_env)
         _run_command(['sudo', 'rm', '-f', '/tmp/svc-map-services'], None, 'rm')
         if upgrade and CONF.enable_validations:  # Run post-upgrade validations
